A little crate that helps with interacting with the system

The lower levels can be hard. So this crate is intended to help with that by abstracing the lower levels to high level code

Re-exports

pub use quork_proc as macros;

Modules

Utilities for checking the users privelages
Utilities to flip booleans
Helper items that will most likely be used in every program.

Macros

Import desired modules for target

Traits

A simple trait to map the return value of a Mutex in a nice little closure